%illustration code for "Adaptive Minimal Confidence Region Rule for Multivariate Initialization Bias Truncation in Discrete-event Simulations"
% by Jianguo Wu, Honglun Xu, Feng Ju and Bill Tseng.


clc
clear
close all

T=200;
h=0.1:0.1:4; % the tuning parameter
load('.\productionLine_data.mat'); % one representative dataset for illustration

for i=1:length(h)
    [volume{i} c_star(i)]=MVCH(X,T,h(i)); % for each h, calculate the truncation point c_star
end

for i=3:length(h)-2
    a1=h(1:i);
    b1=c_star(1:i);
    
    %%%total least square error for two line segments
    err_temp=b1*(a1(end)-a1(1))-a1*(b1(end)-b1(1))+a1(1)*b1(end)-b1(1)*a1(end);
    err1(i)=sum((err_temp).^2)/((a1(end)-a1(1))^2+(b1(end)-b1(1))^2+(a1(1)*b1(end)-b1(1)*a1(end))^2);
    
    a2=h(i:length(h));
    b2=c_star(i:length(h));
    
    err_temp=b2*(a2(end)-a2(1))-a2*(b2(end)-b2(1))+a2(1)*b2(end)-b2(1)*a2(end);
    err2(i)=sum((err_temp).^2)/((a2(end)-a2(1))^2+(b2(end)-b2(1))^2+(a2(1)*b2(end)-b2(1)*a2(end))^2);
    
    Err(i)=(err1(i)+err2(i))/2;
end
[num1,k]=min(Err(3:length(h)-2));  %find the optimal h with minimum total least square
k=k+2;                           
c_star(k)                          % the truncation point c_star with optimal h 



%% illustrate the elbow method to find the optimal h
figure
plot(h,c_star)
hold on
line([h(1),h(k)],[c_star(1),c_star(k)],'color','r')
hold on
line([h(k),h(end)],[c_star(k),c_star(end)],'color','b')


%% show the truncation results using the optimal h
figure

subplot(5,1,1)
plot(X(:,1))
hold on
line([c_star(k),c_star(k)],[min(X(:,1)),max(X(:,1))],'color','r','LineStyle','-.')

subplot(5,1,2)
plot(X(:,2))
hold on
line([c_star(k),c_star(k)],[min(X(:,2)),max(X(:,2))],'color','r','LineStyle','-.')

subplot(5,1,3)
plot(X(:,3))
hold on
line([c_star(k),c_star(k)],[min(X(:,3)),max(X(:,3))],'color','r','LineStyle','-.')

subplot(5,1,4)
plot(X(:,4))
hold on
line([c_star(k),c_star(k)],[min(X(:,4)),max(X(:,4))],'color','r','LineStyle','-.')

subplot(5,1,5)

plot(1:T-50,volume{k})
axis([0,T,0,max(volume{k})])
hold on
line([c_star(k),c_star(k)],[0,max(volume{k})],'color','r','LineStyle','-.')






